.. :Sample:

Sample
======

.. currentmodule:: Data.Sample



.. autosummary::
   :nosignatures:

    Sample.Sample
    Sample.Sample.__init__
    Sample.Sample.initialize
    Sample.Sample.calculateProjections
    Sample.Sample.tr
    Sample.Sample.inv_tr
    Sample.Sample.format_coord
    Sample.Sample.calculateQxQyToHKL
    Sample.Sample.calculateHKLToQxQy
    Sample.Sample.calculateHKLtoProjection
    Sample.Sample.CurratAxe
    	


Sample Object and Methods
---------------------------


.. automodule:: Sample

.. _Sample:

.. autoclass:: Sample
    :members:

    .. automethod:: __init__

